Struct libp2p_rs::kad::Record [−][src]
pub struct Record {
pub key: Key,
pub value: Vec<u8, Global>,
pub time_received: Option<Instant>,
pub publisher: Option<PeerId>,
}A record stored in the DHT.
Fields
key: KeyKey of the record.
value: Vec<u8, Global>Value of the record.
time_received: Option<Instant>The timestamp when the record is received from Kademlia network.
None means record is created locally.
publisher: Option<PeerId>The (original) publisher of the record.
Implementations
impl Record[src]
pub fn new<K>(
key: K,
value: Vec<u8, Global>,
local: bool,
publisher: Option<PeerId>
) -> Record where
K: Into<Key>, [src]
key: K,
value: Vec<u8, Global>,
local: bool,
publisher: Option<PeerId>
) -> Record where
K: Into<Key>,
Creates a new record for insertion into the DHT.
pub fn timestamp(&self) -> Option<Instant>[src]
Returns the timestamp of the record, Instant.